# Scalar Functions

Daft provides a set of built-in operations that can be applied to DataFrame columns. This page provides an overview of all the functions provided by Daft. Learn more about scalar or [column functions](../core_concepts.md#cross-column-aggregations) in Daft User Guide.

::: daft.functions
    options:
        filters: ["!^_", "!row_number", "!rank", "!dense_rank"]

::: daft.functions.llm_generate
    options:
        filters: ["!^_"]
